@@ -26,9 +26,6 @@ AUTHFAILURE_NOPERMISSION = 'AuthFailure.NoPermission'
 # 未授权操作。
 AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 
-# DryRun 操作，代表请求将会是成功的，只是多传了 DryRun 参数。
-DRYRUNOPERATION = 'DryRunOperation'
-
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -56,11 +53,8 @@ FAILEDOPERATION_CLSSERVICENOTACTIVED = 'FailedOperation.ClsServiceNotActived'
 # 集群访问失败。
 FAILEDOPERATION_CLUSTERQUERYFAILED = 'FailedOperation.ClusterQueryFailed'
 
-# 导出Notebook镜像失败
-FAILEDOPERATION_CREATEIMAGEFAILED = 'FailedOperation.CreateImageFailed'
-
-# 启动实例失败。
-FAILEDOPERATION_CREATEJOBINSTANCEFAILED = 'FailedOperation.CreateJobInstanceFailed'
+# 翻页超过1万条，建议重新选择日志查询时间
+FAILEDOPERATION_CONTEXTLIMITERROR = 'FailedOperation.ContextLimitError'
 
 # cos client 内部错误。
 FAILEDOPERATION_DCCOSCLIENTERR = 'FailedOperation.DCCosClientErr'
@@ -128,9 +122,6 @@ FAILEDOPERATION_KMSKEYNOTOPEN = 'FailedOperation.KmsKeyNotOpen'
 # 变更计费配置失败。
 FAILEDOPERATION_MODIFYBILLINGINSTANCEBATCHFAILED = 'FailedOperation.ModifyBillingInstanceBatchFailed'
 
-# 修改计费统计的资源关联标签失败
-FAILEDOPERATION_MODIFYRESOURCEBILLINGTAGSFAILED = 'FailedOperation.ModifyResourceBillingTagsFailed'
-
 # 移动模型目录失败。
 FAILEDOPERATION_MOVEMODELDIRFAILED = 'FailedOperation.MoveModelDirFailed'
 
@@ -143,9 +134,6 @@ FAILEDOPERATION_NOPERMISSION = 'FailedOperation.NoPermission'
 # 操作不允许。
 FAILEDOPERATION_NOTALLOW = 'FailedOperation.NotAllow'
 
-# 该Notebook实例不支持保存镜像，如果您使用的是自定义镜像请重启Notebook实例后再执行保存操作
-FAILEDOPERATION_NOTSUPPORTEDTOCREATEIMAGE = 'FailedOperation.NotSupportedToCreateImage'
-
 # 未找到Notebook实例相关容器，无法生成访问地址。
 FAILEDOPERATION_PODIPNOTFOUND = 'FailedOperation.PodIpNotFound'
 
@@ -158,9 +146,6 @@ FAILEDOPERATION_QUERYBINDINGTAGSFAILED = 'FailedOperation.QueryBindingTagsFailed
 # 数据库查询错误。
 FAILEDOPERATION_QUERYDATABASEFAIL = 'FailedOperation.QueryDatabaseFail'
 
-# 根据标签查询资源失败。
-FAILEDOPERATION_QUERYMODELSBYTAGSFAILED = 'FailedOperation.QueryModelsByTagsFailed'
-
 # 查询计费价格失败。
 FAILEDOPERATION_QUERYPRICEFAILED = 'FailedOperation.QueryPriceFailed'
 
@@ -179,6 +164,9 @@ FAILEDOPERATION_QUERYTAGFAIL = 'FailedOperation.QueryTagFail'
 # 记录不存在。
 FAILEDOPERATION_RECORDNOTFOUND = 'FailedOperation.RecordNotFound'
 
+# 释放SSH端口失败
+FAILEDOPERATION_RELEASESSHPORTFAILED = 'FailedOperation.ReleaseSSHPortFailed'
+
 # 存储库有绑定的实例，请先删除绑定的实例。
 FAILEDOPERATION_REPOBINDBYINSTANCE = 'FailedOperation.RepoBindByInstance'
 
@@ -197,6 +185,9 @@ FAILEDOPERATION_UNBINDINGTAGSFAILED = 'FailedOperation.UnBindingTagsFailed'
 # 当前任务后台提交重试中，不允许操作停止，请稍后再试。
 FAILEDOPERATION_UNSUBMITNOTALLOWTOSTOP = 'FailedOperation.UnSubmitNotAllowToStop'
 
+# 无操作权限
+FAILEDOPERATION_UNAUTHORIZEDOPERATION = 'FailedOperation.UnauthorizedOperation'
+
 # 解冻失败。
 FAILEDOPERATION_UNFREEZEBILLFAILED = 'FailedOperation.UnfreezeBillFailed'
 
@@ -215,14 +206,26 @@ INTERNALERROR_BINDINGTAGSFAILED = 'InternalError.BindingTagsFailed'
 # 文件系统不存在
 INTERNALERROR_CFSNOTFOUND = 'InternalError.CFSNotFound'
 
+# 校验文件系统路径权限失败
+INTERNALERROR_CHECKFSPATHACCESSIBILITYFAILED = 'InternalError.CheckFSPathAccessibilityFailed'
+
+# 创建自定义密钥失败
+INTERNALERROR_CREATECUSTOMSECRETFAILED = 'InternalError.CreateCustomSecretFailed'
+
 # 创建JOB失败
 INTERNALERROR_CREATEJOBINSTANCEFAILED = 'InternalError.CreateJobInstanceFailed'
 
 # 创建TCR镜像仓库长期访问凭证失败
 INTERNALERROR_CREATETCRINSTANCETOKENFAILED = 'InternalError.CreateTcrInstanceTokenFailed'
 
-# 冻结失败。
-INTERNALERROR_FREEZEBILLFAILED = 'InternalError.FreezeBillFailed'
+# 删除自定义密钥失败
+INTERNALERROR_DELETECUSTOMSECRETFAILED = 'InternalError.DeleteCustomSecretFailed'
+
+# 查询自定义密钥失败
+INTERNALERROR_DESCRIBECUSTOMSECRETFAILED = 'InternalError.DescribeCustomSecretFailed'
+
+# 获取用户依赖权限失败
+INTERNALERROR_DESCRIBESUBUINDEPENDENCYACCESSIBILITYFAILED = 'InternalError.DescribeSubuinDependencyAccessibilityFailed'
 
 # 查询文件系统信息失败
 INTERNALERROR_GETCFSFILESYSTEMSFAILED = 'InternalError.GetCFSFileSystemsFailed'
@@ -230,8 +233,8 @@ INTERNALERROR_GETCFSFILESYSTEMSFAILED = 'InternalError.GetCFSFileSystemsFailed'
 # 查询文件系统挂载信息失败。
 INTERNALERROR_GETCFSMOUNTINFOFAILED = 'InternalError.GetCFSMountInfoFailed'
 
-# 余额不足。
-INTERNALERROR_INSUFFICIENTBALANCE = 'InternalError.InsufficientBalance'
+# 修改自定义密钥失败
+INTERNALERROR_MODIFYCUSTOMSECRETFAILED = 'InternalError.ModifyCustomSecretFailed'
 
 # 没有权限。
 INTERNALERROR_NOPERMISSION = 'InternalError.NoPermission'
@@ -260,15 +263,21 @@ INTERNALERROR_QUERYRESOURCESPECFAILED = 'InternalError.QueryResourceSpecFailed'
 # 查询子网信息失败。
 INTERNALERROR_QUERYSUBNETINFOFAILED = 'InternalError.QuerySubnetInfoFailed'
 
-# 查询用户临时秘钥失败
+# 查询用户临时密钥失败
 INTERNALERROR_QUERYUSERTMPCREDENTIALFAILED = 'InternalError.QueryUserTMPCredentialFailed'
 
+# 查询vpc信息失败
+INTERNALERROR_QUERYVPCINFOFAILED = 'InternalError.QueryVPCInfoFailed'
+
 # 停止任务失败。
 INTERNALERROR_STOPJOBINSTANCEFAILED = 'InternalError.StopJobInstanceFailed'
 
 # 未提交状态禁止停止
 INTERNALERROR_UNSUBMITTEDSTATUSNOTALLOWSTOP = 'InternalError.UnSubmittedStatusNotAllowStop'
 
+# 校验任务参数失败
+INTERNALERROR_VALIDATECREATETASKFAILED = 'InternalError.ValidateCreateTaskFailed'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -284,8 +293,8 @@ INVALIDPARAMETER_MODELISOFFLINE = 'InvalidParameter.ModelIsOffline'
 # 无效的接口。
 INVALIDPARAMETER_TGWINVALIDINTERFACE = 'InvalidParameter.TgwInvalidInterface'
 
-# 无效的请求包体。
-INVALIDPARAMETER_TGWINVALIDREQUESTBODY = 'InvalidParameter.TgwInvalidRequestBody'
+# 不支持使用多个本地磁盘
+INVALIDPARAMETER_UNSUPPORTEDMULTILOCALDISK = 'InvalidParameter.UnsupportedMultiLocalDisk'
 
 # 请求参数校验失败。
 INVALIDPARAMETER_VALIDATEERROR = 'InvalidParameter.ValidateError'
@@ -308,6 +317,12 @@ INVALIDPARAMETERVALUE_BACKOFFLIMITNOTSUPPORT = 'InvalidParameterValue.BackOffLim
 # 名称不合法。
 INVALIDPARAMETERVALUE_BADNAME = 'InvalidParameterValue.BadName'
 
+# 云联网未被关联VPC
+INVALIDPARAMETERVALUE_CCNHASNOATTACHEDVPC = 'InvalidParameterValue.CcnHasNoAttachedVpc'
+
+# CFS路径与现存的数据有冲突
+INVALIDPARAMETERVALUE_CFSPATHCOLLISION = 'InvalidParameterValue.CfsPathCollision'
+
 # 请设置日志集、日志主题ID。
 INVALIDPARAMETERVALUE_CLSCONFIGREQUIRED = 'InvalidParameterValue.ClsConfigRequired'
 
@@ -341,6 +356,9 @@ INVALIDPARAMETERVALUE_DCDATASETTYPE = 'InvalidParameterValue.DCDatasetType'
 # 不支持的过滤参数。
 INVALIDPARAMETERVALUE_DCFILTERVALUES = 'InvalidParameterValue.DCFilterValues'
 
+# 数据配置数量超过最大限制
+INVALIDPARAMETERVALUE_DATACONFIGNUMLIMITEXCEEDED = 'InvalidParameterValue.DataConfigNumLimitExceeded'
+
 # 数据集不存在
 INVALIDPARAMETERVALUE_DATASETNOTEXIST = 'InvalidParameterValue.DatasetNotExist'
 
@@ -350,6 +368,9 @@ INVALIDPARAMETERVALUE_DATASETNUMLIMITEXCEEDED = 'InvalidParameterValue.DatasetNu
 # 实例名称冲突，请更换名称后重试。
 INVALIDPARAMETERVALUE_DUPLICATENAME = 'InvalidParameterValue.DuplicateName'
 
+# 文件系统路径访问权限受限
+INVALIDPARAMETERVALUE_FSPATHINACCESSIBLE = 'InvalidParameterValue.FSPathInaccessible'
+
 # 训练框架对应的版本不支持，请阅读文档查看TIONE目前支持的框架和版本。
 INVALIDPARAMETERVALUE_FRAMEWORKVERSIONNOTSUPPORT = 'InvalidParameterValue.FrameworkVersionNotSupport'
 
@@ -365,12 +386,24 @@ INVALIDPARAMETERVALUE_GOOSEFSCONFIGCANNOTEMPTY = 'InvalidParameterValue.GooseFSC
 # 所选的GooseFS实例不存在
 INVALIDPARAMETERVALUE_GOOSEFSNOTEXIST = 'InvalidParameterValue.GooseFSNotExist'
 
+# 镜像地址不合法，请重新填写
+INVALIDPARAMETERVALUE_IMAGEADDRESSILLEGAL = 'InvalidParameterValue.ImageAddressIllegal'
+
+# 镜像地址不合法
+INVALIDPARAMETERVALUE_IMAGEILLEGAL = 'InvalidParameterValue.ImageIllegal'
+
 # 训练任务镜像不存在。
 INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'
 
 # 无效的过滤器。
 INVALIDPARAMETERVALUE_INVALIDFILTER = 'InvalidParameterValue.InvalidFilter'
 
+# 非法镜像
+INVALIDPARAMETERVALUE_INVALIDIMAGENAME = 'InvalidParameterValue.InvalidImageName'
+
+# 非法资源规格
+INVALIDPARAMETERVALUE_INVALIDRESOURCESPEC = 'InvalidParameterValue.InvalidResourceSpec'
+
 # 生命周期脚本无效。
 INVALIDPARAMETERVALUE_LIFECYCLENOTFOUND = 'InvalidParameterValue.LifecycleNotFound'
 
@@ -395,6 +428,9 @@ INVALIDPARAMETERVALUE_PAGELIMITEXCEEDED = 'InvalidParameterValue.PageLimitExceed
 # 参数长度超过限制
 INVALIDPARAMETERVALUE_PARAMLENGTHEXCEEDLIMIT = 'InvalidParameterValue.ParamLengthExceedLimit'
 
+# 本地盘路径不合法
+INVALIDPARAMETERVALUE_PATHILLEGAL = 'InvalidParameterValue.PathIllegal'
+
 # 查询vpc信息失败
 INVALIDPARAMETERVALUE_QUERYVPCINFOFAILED = 'InvalidParameterValue.QueryVPCInfoFailed'
 
@@ -419,8 +455,8 @@ INVALIDPARAMETERVALUE_UNSUPPORTEDDATACONFIG = 'InvalidParameterValue.Unsupported
 # 不支持使用GooseFS实例
 INVALIDPARAMETERVALUE_UNSUPPORTEDGOOSEFSCONFIG = 'InvalidParameterValue.UnsupportedGooseFSConfig'
 
-# Notebook卷大小只能增加，如需减小容量请重新创建实例。
-INVALIDPARAMETERVALUE_VOLUMESHRINKNOTALLOW = 'InvalidParameterValue.VolumeShrinkNotAllow'
+# 不支持同一实例挂载多个CBS存储
+INVALIDPARAMETERVALUE_UNSUPPORTEDMULTICBSSTORAGE = 'InvalidParameterValue.UnsupportedMultiCBSStorage'
 
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
@@ -437,12 +473,12 @@ OPERATIONDENIED_BALANCEINSUFFICIENT = 'OperationDenied.BalanceInsufficient'
 # 计费平台出错
 OPERATIONDENIED_BILLINGEXCEPTION = 'OperationDenied.BillingException'
 
+# 资源类型不支持，请检查白名单配置
+OPERATIONDENIED_BILLINGSTATUSNOTSUPPORTWHITELISTGPUTYPE = 'OperationDenied.BillingStatusNotSupportWhitelistGPUType'
+
 # 按量计费资源售罄。
 OPERATIONDENIED_BILLINGSTATUSRESOURCEINSUFFICIENT = 'OperationDenied.BillingStatusResourceInsufficient'
 
-# vpc 和 子网 禁止修改
-OPERATIONDENIED_FORBIDMODIFYVPCANDSUBNET = 'OperationDenied.ForbidModifyVpcAndSubnet'
-
 # IP不合法。
 OPERATIONDENIED_IPILLEGAL = 'OperationDenied.IpIllegal'
 
@@ -455,8 +491,8 @@ OPERATIONDENIED_NETWORKCIDRILLEGAL = 'OperationDenied.NetworkCidrIllegal'
 # 操作不允许
 OPERATIONDENIED_NOTALLOW = 'OperationDenied.NotAllow'
 
-# 存量Notebook不支持保存
-OPERATIONDENIED_NOTSUPPORTSAVEIMAGE = 'OperationDenied.NotSupportSaveImage'
+# 当前资源组已开启资源按GPU比例预设，仅支持提交含GPU资源的任务
+OPERATIONDENIED_NOTSUPPORTCUSTOMRESOURCE = 'OperationDenied.NotSupportCustomResource'
 
 # 预付费资源组余量不足。
 OPERATIONDENIED_RESOURCEGROUPINSUFFICIENT = 'OperationDenied.ResourceGroupInsufficient'
@@ -467,6 +503,9 @@ OPERATIONDENIED_SUBNETILLEGAL = 'OperationDenied.SubnetIllegal'
 # 太极应用组存量资源不足，不满足训练要求
 OPERATIONDENIED_TAIJIAPPLICATIONGROUPINSUFFICIENT = 'OperationDenied.TAIJIApplicationGroupInsufficient'
 
+# 无访问权限
+OPERATIONDENIED_UNAUTHORIZEDOPERATION = 'OperationDenied.UnauthorizedOperation'
+
 # 白名单免费配额不足。
 OPERATIONDENIED_WHITELISTQUOTAEXCEED = 'OperationDenied.WhitelistQuotaExceed'
 
@@ -476,12 +515,24 @@ RESOURCEINUSE = 'ResourceInUse'
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
+# SSH端口资源耗尽
+RESOURCEINSUFFICIENT_SSHPORTISCONSUMEDUP = 'ResourceInsufficient.SSHPortIsConsumedUp'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# 文件系统不存在
+RESOURCENOTFOUND_CFSNOTFOUND = 'ResourceNotFound.CfsNotFound'
+
 # 没有该模型。
 RESOURCENOTFOUND_NOMODEL = 'ResourceNotFound.NoModel'
 
+# 资源组不存在
+RESOURCENOTFOUND_RESOURCEGROUPNOTFOUND = 'ResourceNotFound.ResourceGroupNotFound'
+
+# vpc不存在
+RESOURCENOTFOUND_VPCNOTFOUND = 'ResourceNotFound.VPCNotFound'
+
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
